@@ -12,20 +12,19 @@ test_that("can find the correct first level .pred name", {
 
   expect_equal(first_class_prob_name(preds, "first", "Class"), quote(.pred_Class1))
   expect_equal(first_class_prob_name(preds, "second", "Class"), quote(.pred_Class2))
-  expect_error(
-    first_class_prob_name(preds, "Potato", "Class"),
-    '`event_level` must be one of "first" or "second"'
+  expect_snapshot(
+    error = TRUE,
+    first_class_prob_name(preds, "Potato", "Class")
   )
-  expect_error(
-    first_class_prob_name(preds, "first", "Potato"),
-    "'Potato' is not a column in the dataset"
+  expect_snapshot(
+    error = TRUE,
+    first_class_prob_name(preds, "first", "Potato")
   )
-  expect_error(
-    first_class_prob_name(preds, first, "Class"),
-    "`event_level` must be a character vector"
+  expect_snapshot(
+    error = TRUE,
+    first_class_prob_name(preds, first, "Class")
   )
-  expect_error(
-    first_class_prob_name(preds, "first", Class),
-    "object 'Class' not found"
+  expect_snapshot_error(
+    first_class_prob_name(preds, "first", Class)
   )
 })
